# -*- coding: utf-8 -*-

"""sftp tools"""


# ----------------------- Imports --------------------------------
from pathlib import Path
import stat
import re

#--------------------------Functions------------------------------

def sftp_walk(self, remotepath):
    """
    Kindof a stripped down version of os.walk, implemented for sftp.
    """
    remotepath = remotepath.replace('\\', '/')
    path = remotepath
    files = []
    folders = []
    for f in self.listdir_iter(remotepath):
        if stat.S_ISDIR(f.st_mode):
            folders.append(f.filename)
        else:
            files.append(f.filename)
    #  print(path, folders, files)
    yield path, folders, files
    for folder in folders:
        new_path = str(Path(remotepath).joinpath(folder))
        for x in sftp_walk(self, new_path):
            yield x

def paramiko_glob(remote_path, pattern, sftp_client):
    """Search recursively for files matching a given pattern. Stop recursivity when found !!!!
    Inspired from:
    https://gist.github.com/lkluft/ddda28208f7658d93f8238ad88bd45f2
    Parameters:
        path (str): Path to directory on remote machine.
        pattern (str): Python re [0] pattern for filenames.
        sftp_client (SFTPClient): paramiko SFTPClient.
    Return : list of path (str)

    [0] https://docs.python.org/2/library/re.html

    """
    p = re.compile(pattern)
    root_dirs = sftp_client.listdir_attr(remote_path)
    file_list = []

    # Loop over all entries in given path...
    for f in root_dirs:
        # ... if it is a file, check the name pattern and append it to file_list.
        if p.match(f.filename):
            file_list.append(str(Path(remote_path).joinpath(f.filename)))
            break   # quand le trouve ne va pas plus loin dans le path !!!!!!!!!!!!!!
        # ... if it is a directory call paramiko_glob recursively.
        if stat.S_ISDIR(f.st_mode):
            file_list += paramiko_glob(str(Path(remote_path).joinpath(f.filename)), pattern, sftp_client)
    return file_list



